Learn R Programming

timefully (version 0.1.0)

convert_time_num_to_period: Convert numeric time value to a datetime period (hour-based)

Description

Convert numeric time value to a datetime period (hour-based)

Usage

convert_time_num_to_period(time_num)

Value

lubridate::period vector with hours and minutes corresponding to the numeric input.

Arguments

time_num

Numeric time value (hour-based)

Examples

Run this code
convert_time_num_to_period(1.5)
convert_time_num_to_period(c(0.25, 2))

Run the code above in your browser using DataLab