Skip to contents

Change datetime format

Usage

format_date_axis(format_list, locale = "nl-NL")

Arguments

format_list

(named list) ORDER matters key and type of output as value

locale

(str) locale to use in settings for example nl-NL (default)

Value

js code as a string to change datetime axis