Learn R Programming

timefully (version 0.1.0)

get_timeseries_tzone: Get the time zone of a time series dataframe

Description

Get the time zone of a time series dataframe

Usage

get_timeseries_tzone(dtf)

Value

character

Arguments

dtf

data.frame or tibble, first column of name datetime being of class datetime and rest of columns being numeric

Examples

Run this code
get_timeseries_tzone(dtf)

Run the code above in your browser using DataLab