Learn R Programming

timefully (version 0.1.0)

to_hhmm: Convert a number of minutes in string format "HH:MM"

Description

Convert a number of minutes in string format "HH:MM"

Usage

to_hhmm(mins)

Value

character

Arguments

mins

integer, number of minutes (from 0 to 1439)

Examples

Run this code
to_hhmm(75)

Run the code above in your browser using DataLab