powered by
Convert numeric time value to a datetime period (hour-based)
convert_time_num_to_period(time_num)
lubridate::period vector with hours and minutes corresponding to the numeric input.
lubridate::period
Numeric time value (hour-based)
convert_time_num_to_period(1.5) convert_time_num_to_period(c(0.25, 2))
Run the code above in your browser using DataLab