powered by
Get the time zone of a time series dataframe
get_timeseries_tzone(dtf)
character
data.frame or tibble, first column of name datetime being of class datetime and rest of columns being numeric
datetime
Run the code above in your browser using DataLab