Note that timefully considers a full datetime sequence when days are complete.
Examples
has_timeseries_gaps(dtf)
#> [1] FALSE
dtf_gaps <- dtf[c(1:3, 7:10), ]
has_timeseries_gaps(dtf_gaps)
#> [1] TRUE
Note that timefully considers a full datetime sequence when days are complete.
has_timeseries_gaps(dtf)
#> [1] FALSE
dtf_gaps <- dtf[c(1:3, 7:10), ]
has_timeseries_gaps(dtf_gaps)
#> [1] TRUE